Installation
************

Renate is available via PyPI and can be installed using :code:`pip`:

.. code-block:: bash

    pip install renate

Alternatively, if you want to access the code directly (e.g., for developing and running new methods)
it is possible to clone the git repository

.. code-block:: bash

    git clone https://github.com/awslabs/renate.git

We also recommend using a virtual environment to avoid conflicts in the 
versions of the packages installed. For example, following
`these instructions <https://docs.python.org/3/library/venv.html>`_ to use :code:`venv`.
